@@ -1,16 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 import codecs
-import distutils.spawn
 import os.path
 import platform
-import re
 import sys
 import subprocess
-from PyQt5 import QtCore, QtGui, QtWidgets
+from PyQt5 import QtWidgets
 
 from functools import partial
-from collections import defaultdict
 
 try:
     from PyQt5.QtGui import *
@@ -29,7 +26,6 @@ except ImportError:
     from PyQt4.QtGui import *
     from PyQt4.QtCore import *
 
-import resources
 # Add internal libs
 from libs.constants import *
 from libs.utils import *
@@ -51,8 +47,8 @@ from libs.yolo_io import TXT_EXT
 from libs.ustr import ustr
 from libs.version import __version__
 from libs.hashableQListWidgetItem import HashableQListWidgetItem
-import detectStoma
-from generateExcel import generaExcel
+from predict import detectStoma
+from predict.generateExcel import generaExcel
 import notebooks.notebookmenu
 import notebooks.notebookYolo
 import notebooks.mainModel
